cmd

package
v1.2.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 25, 2018 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AddRendererFlags

func AddRendererFlags(c *cobra.Command)

AddRendererFlags adds a set of flags to make the use of the program more flexible

func Initialize

func Initialize()

Initialize will be run when cobra finishes its initialization

Types

This section is empty.

Jump to